Index: webrtc/modules/rtp_rtcp/include/rtp_rtcp.h |
diff --git a/webrtc/modules/rtp_rtcp/include/rtp_rtcp.h b/webrtc/modules/rtp_rtcp/include/rtp_rtcp.h |
index bfd8e657432b2dc6197e9aab0d7f130a47d8f232..9c2b231795294573d3c8dddba683fa1e6eae7082 100644 |
--- a/webrtc/modules/rtp_rtcp/include/rtp_rtcp.h |
+++ b/webrtc/modules/rtp_rtcp/include/rtp_rtcp.h |
@@ -294,25 +294,42 @@ class RtpRtcp : public Module { |
* Used by the codec module to deliver a video or audio frame for |
* packetization. |
* |
* frameType - type of frame to send |
* payloadType - payload type of frame to send |
* timestamp - timestamp of frame to send |
* payloadData - payload buffer of frame to send |
* payloadSize - size of payload buffer to send |
* fragmentation - fragmentation offset data for fragmented frames such |
* as layers or RED |
* |
* return -1 on failure else 0 |
*/ |
virtual int32_t SendOutgoingData( |
- FrameType frameType, |
- int8_t payloadType, |
- uint32_t timeStamp, |
+ FrameType frame_type, |
+ int8_t payload_type, |
+ uint32_t timestamp, |
int64_t capture_time_ms, |
- const uint8_t* payloadData, |
- size_t payloadSize, |
- const RTPFragmentationHeader* fragmentation = NULL, |
- const RTPVideoHeader* rtpVideoHdr = NULL) = 0; |
+ const uint8_t* payload_data, |
+ size_t payload_size, |
+ const RTPFragmentationHeader* fragmentation, |
+ const RTPVideoHeader* rtp_video_header, |
+ uint32_t* frame_id_out) = 0; |
+ |
+ // Deprecated version of the methood above. |
stefan-webrtc
2016/07/28 08:51:17
method
Sergey Ulanov
2016/07/28 20:52:46
Done.
|
+ int32_t SendOutgoingData( |
+ FrameType frame_type, |
+ int8_t payload_type, |
+ uint32_t timestamp, |
+ int64_t capture_time_ms, |
+ const uint8_t* payload_data, |
+ size_t payload_size, |
+ const RTPFragmentationHeader* fragmentation = nullptr, |
+ const RTPVideoHeader* rtp_video_header = nullptr) { |
+ return SendOutgoingData(frame_type, payload_type, timestamp, |
+ capture_time_ms, payload_data, payload_size, |
+ fragmentation, rtp_video_header, |
+ /*frame_id_out=*/nullptr); |
+ } |
virtual bool TimeToSendPacket(uint32_t ssrc, |
uint16_t sequence_number, |
@@ -294,25 +294,42 @@ class RtpRtcp : public Module { |
* packetization. |
* |
- * frameType - type of frame to send |
- * payloadType - payload type of frame to send |
+ * frame_type - type of frame to send |
+ * payload_type - payload type of frame to send |
* timestamp - timestamp of frame to send |
@@ -294,25 +294,42 @@ class RtpRtcp : public Module { |
* timestamp - timestamp of frame to send |
- * payloadData - payload buffer of frame to send |
- * payloadSize - size of payload buffer to send |
+ * payload_data - payload buffer of frame to send |
+ * payload_size - size of payload buffer to send |
* fragmentation - fragmentation offset data for fragmented frames such |
* as layers or RED |